Description Usage Arguments Value Examples
Creates a NUTS2-level ggmap from UK Postcode data
1 |
mapdata |
Data frame of postcode values to be plotted |
series |
The name of the data series to plot |
match_on |
Optional. The name of the postcode level to join against. Must be one of:
|
ggmap object
1 | geomap(sample_data, "population")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.